# pycoin_rs

Rust and pyo3-based speed-ups for pycoin.

This is a rust-based python wheel that wraps [rust-bitcoin](https://docs.rs/bitcoin/latest/bitcoin/).

The plan is to integrate it with `pycoin` as an optional drop-in to speed up slow operations implemented in python.
